@@ -12,9 +12,10 @@
  * Gets some core libraries
  */
 require_once 'libraries/common.inc.php';
-require_once 'libraries/DbSearch.class.php';
 
-$response = PMA_Response::getInstance();
+use PMA\libraries\DbSearch;
+
+$response = PMA\libraries\Response::getInstance();
 $header   = $response->getHeader();
 $scripts  = $header->getScripts();
 $scripts->addFile('db_search.js');
@@ -24,9 +25,9 @@ $scripts->addFile('jquery/jquery-ui-timepicker-addon.js');
 
 require 'libraries/db_common.inc.php';
 
-// If config variable $GLOBALS['cfg']['Usedbsearch'] is on false : exit.
+// If config variable $GLOBALS['cfg']['UseDbSearch'] is on false : exit.
 if (! $GLOBALS['cfg']['UseDbSearch']) {
-    PMA_Util::mysqlDie(
+    PMA\libraries\Util::mysqlDie(
         __('Access denied!'), '', false, $err_url
     );
 } // end if
@@ -34,11 +35,21 @@ $url_query .= '&amp;goto=db_search.php';
 $url_params['goto'] = 'db_search.php';
 
 // Create a database search instance
-$db_search = new PMA_DbSearch($GLOBALS['db']);
+$db_search = new DbSearch($GLOBALS['db']);
 
 // Display top links if we are not in an Ajax request
-if ( $GLOBALS['is_ajax_request'] != true) {
-    include 'libraries/db_info.inc.php';
+if ($GLOBALS['is_ajax_request'] != true) {
+    list(
+        $tables,
+        $num_tables,
+        $total_num_tables,
+        $sub_part,
+        $is_show_stats,
+        $db_is_system_schema,
+        $tooltip_truename,
+        $tooltip_aliasname,
+        $pos
+    ) = PMA\libraries\Util::getDbInfo($db, isset($sub_part) ? $sub_part : '');
 }
 
 // Main search form has been submitted, get results
@@ -60,4 +71,3 @@ $response->addHTML(
 );
 $response->addHTML($db_search->getSelectionForm());
 $response->addHTML($db_search->getResultDivs());
-?>
