@@ -5,6 +5,7 @@
  *
  * @package PhpMyAdmin
  */
+use PMA\libraries\RecentFavoriteTable;
 
 /**
  * Gets some core libraries and displays a top message if required
@@ -38,9 +39,9 @@ unset($drops, $each_drop);
  * Such scripts must not be loaded on home page.
  *
  */
- $target_blacklist = array (
+$target_blacklist = array (
     'import.php', 'export.php'
-    );
+);
 
 // If we have a valid target, let's load that script instead
 if (! empty($_REQUEST['target'])
@@ -61,9 +62,13 @@ if (isset($_REQUEST['ajax_request']) && ! empty($_REQUEST['access_time'])) {
 if (! empty($_REQUEST['db'])) {
     $page = null;
     if (! empty($_REQUEST['table'])) {
-        $page = $GLOBALS['cfg']['DefaultTabTable'];
+        $page = PMA\libraries\Util::getScriptNameForOption(
+            $GLOBALS['cfg']['DefaultTabTable'], 'table'
+        );
     } else {
-        $page = $GLOBALS['cfg']['DefaultTabDatabase'];
+        $page = PMA\libraries\Util::getScriptNameForOption(
+            $GLOBALS['cfg']['DefaultTabDatabase'], 'database'
+        );
     }
     include $page;
     exit;
@@ -72,12 +77,11 @@ if (! empty($_REQUEST['db'])) {
 /**
  * Check if it is an ajax request to reload the recent tables list.
  */
-require_once 'libraries/RecentFavoriteTable.class.php';
 if ($GLOBALS['is_ajax_request'] && ! empty($_REQUEST['recent_table'])) {
-    $response = PMA_Response::getInstance();
+    $response = PMA\libraries\Response::getInstance();
     $response->addJSON(
         'list',
-        PMA_RecentFavoriteTable::getInstance('recent')->getHtmlList()
+        RecentFavoriteTable::getInstance('recent')->getHtmlList()
     );
     exit;
 }
@@ -97,7 +101,7 @@ $show_query = '1';
 
 // Any message to display?
 if (! empty($message)) {
-    echo PMA_Util::getMessage($message);
+    echo PMA\libraries\Util::getMessage($message);
     unset($message);
 }
 
@@ -108,7 +112,6 @@ $mysql_cur_user_and_host = '';
 // all MySQL-related information
 if ($server > 0) {
     include 'libraries/server_common.inc.php';
-    include 'libraries/StorageEngine.class.php';
 
     // Use the verbose name of the server instead of the hostname
     // if a value is set
@@ -133,15 +136,15 @@ if ($server > 0) {
                 : $GLOBALS['cfg']['Server']['host']);
 }
 
-echo '<div id="maincontainer">' . "\n";
+echo '<div id="maincontainer">' , "\n";
 // Anchor for favorite tables synchronization.
-echo PMA_RecentFavoriteTable::getInstance('favorite')->getHtmlSyncFavoriteTables();
+echo RecentFavoriteTable::getInstance('favorite')->getHtmlSyncFavoriteTables();
 echo '<div id="main_pane_left">';
 if ($server > 0 || count($cfg['Servers']) > 1
 ) {
     if ($cfg['DBG']['demo']) {
         echo '<div class="group">';
-        echo '<h2>' . __('phpMyAdmin Demo Server') . '</h2>';
+        echo '<h2>' , __('phpMyAdmin Demo Server') , '</h2>';
         echo '<p style="margin: 0.5em 1em 0.5em 1em">';
         printf(
             __(
@@ -149,13 +152,13 @@ if ($server > 0 || count($cfg['Servers']) > 1
                 . 'please do not change root, debian-sys-maint and pma users. '
                 . 'More information is available at %s.'
             ),
-            '<a href="http://demo.phpmyadmin.net/">demo.phpmyadmin.net</a>'
+            '<a href="url.php?url=https://demo.phpmyadmin.net/" target="_blank" rel="noopener noreferrer">demo.phpmyadmin.net</a>'
         );
         echo '</p>';
         echo '</div>';
     }
     echo '<div class="group">';
-    echo '<h2>' . __('General Settings') . '</h2>';
+    echo '<h2>' , __('General settings') , '</h2>';
     echo '<ul>';
 
     /**
@@ -168,14 +171,15 @@ if ($server > 0 || count($cfg['Servers']) > 1
     ) {
         echo '<li id="li_select_server" class="no_bullets" >';
         include_once 'libraries/select_server.lib.php';
-        echo PMA_Util::getImage('s_host.png') . " " . PMA_selectServer(true, true);
+        echo PMA\libraries\Util::getImage('s_host.png') , " "
+            , PMA_selectServer(true, true);
         echo '</li>';
     }
 
     /**
      * Displays the mysql server related links
      */
-    if ($server > 0 && ! PMA_DRIZZLE) {
+    if ($server > 0) {
         include_once 'libraries/check_user_privileges.lib.php';
 
         // Logout for advanced authentication
@@ -183,7 +187,9 @@ if ($server > 0 || count($cfg['Servers']) > 1
             if ($cfg['ShowChgPassword']) {
                 $conditional_class = 'ajax';
                 PMA_printListItem(
-                    PMA_Util::getImage('s_passwd.png') . " " . __('Change password'),
+                    PMA\libraries\Util::getImage('s_passwd.png') . "&nbsp;" . __(
+                        'Change password'
+                    ),
                     'li_change_password',
                     'user_password.php' . $common_url_query,
                     null,
@@ -195,13 +201,13 @@ if ($server > 0 || count($cfg['Servers']) > 1
             }
         } // end if
         echo '    <li id="li_select_mysql_collation" class="no_bullets" >';
-        echo '        <form method="post" action="index.php">' . "\n"
+        echo '        <form method="post" action="index.php">' , "\n"
            . PMA_URL_getHiddenInputs(null, null, 4, 'collation_connection')
            . '            <label for="select_collation_connection">' . "\n"
-           . '                ' . PMA_Util::getImage('s_asci.png') . " "
-                               . __('Server connection collation') . "\n"
+           . '                ' . PMA\libraries\Util::getImage('s_asci.png')
+            . "&nbsp;" . __('Server connection collation') . "\n"
            // put the doc link in the form so that it appears on the same line
-           . PMA_Util::showMySQLDocu('Charset-connection')
+           . PMA\libraries\Util::showMySQLDocu('Charset-connection')
            . ': ' .  "\n"
            . '            </label>' . "\n"
 
@@ -215,20 +221,21 @@ if ($server > 0 || count($cfg['Servers']) > 1
            )
            . '        </form>' . "\n"
            . '    </li>' . "\n";
-    } // end of if ($server > 0 && !PMA_DRIZZLE)
+    } // end of if ($server > 0)
     echo '</ul>';
     echo '</div>';
 }
 
 echo '<div class="group">';
-echo '<h2>' . __('Appearance Settings') . '</h2>';
+echo '<h2>' , __('Appearance settings') , '</h2>';
 echo '  <ul>';
 
 // Displays language selection combo
-if (empty($cfg['Lang']) && count($GLOBALS['available_languages']) > 1) {
+if (empty($cfg['Lang'])) {
     echo '<li id="li_select_lang" class="no_bullets">';
     include_once 'libraries/display_select_lang.lib.php';
-    echo PMA_Util::getImage('s_lang.png') . " " . PMA_getLanguageSelectorHtml();
+    echo PMA\libraries\Util::getImage('s_lang.png') , " "
+        , PMA_getLanguageSelectorHtml();
     echo '</li>';
 }
 
@@ -236,12 +243,12 @@ if (empty($cfg['Lang']) && count($GLOBALS['available_languages']) > 1) {
 
 if ($GLOBALS['cfg']['ThemeManager']) {
     echo '<li id="li_select_theme" class="no_bullets">';
-    echo PMA_Util::getImage('s_theme.png') . " "
-            .  $_SESSION['PMA_Theme_Manager']->getHtmlSelectBox();
+    echo PMA\libraries\Util::getImage('s_theme.png') , " "
+            ,  $_SESSION['PMA_Theme_Manager']->getHtmlSelectBox();
     echo '</li>';
 }
 echo '<li id="li_select_fontsize">';
-echo PMA_Config::getFontsizeForm();
+echo PMA\libraries\Config::getFontsizeForm();
 echo '</li>';
 
 echo '</ul>';
@@ -251,7 +258,9 @@ echo '</ul>';
 if ($server > 0) {
     echo '<ul>';
     PMA_printListItem(
-        PMA_Util::getImage('b_tblops.png') . " " . __('More settings'),
+        PMA\libraries\Util::getImage('b_tblops.png') . "&nbsp;" . __(
+            'More settings'
+        ),
         'li_user_preferences',
         'prefs_manage.php' . $common_url_query,
         null,
@@ -272,14 +281,14 @@ echo '<div id="main_pane_right">';
 if ($server > 0 && $GLOBALS['cfg']['ShowServerInfo']) {
 
     echo '<div class="group">';
-    echo '<h2>' . __('Database server') . '</h2>';
-    echo '<ul>' . "\n";
+    echo '<h2>' , __('Database server') , '</h2>';
+    echo '<ul>' , "\n";
     PMA_printListItem(
         __('Server:') . ' ' . $server_info,
         'li_server_info'
     );
     PMA_printListItem(
-        __('Server type:') . ' ' . PMA_Util::getServerType(),
+        __('Server type:') . ' ' . PMA\libraries\Util::getServerType(),
         'li_server_type'
     );
     PMA_printListItem(
@@ -298,13 +307,10 @@ if ($server > 0 && $GLOBALS['cfg']['ShowServerInfo']) {
     );
 
     echo '    <li id="li_select_mysql_charset">';
-    echo '        ' . __('Server charset:') . ' '
+    echo '        ' , __('Server charset:') , ' '
        . '        <span lang="en" dir="ltr">';
-    if (! PMA_DRIZZLE) {
-        echo '           '
-            . $mysql_charsets_descriptions[$mysql_charset_map['utf-8']];
-    }
-    echo '           (' . $mysql_charset_map['utf-8'] . ')'
+    echo '           ' , $mysql_charsets_descriptions[$mysql_charset_map['utf-8']];
+    echo '           (' , $mysql_charset_map['utf-8'] , ')'
        . '        </span>'
        . '    </li>'
        . '  </ul>'
@@ -313,7 +319,7 @@ if ($server > 0 && $GLOBALS['cfg']['ShowServerInfo']) {
 
 if ($GLOBALS['cfg']['ShowServerInfo'] || $GLOBALS['cfg']['ShowPhpInfo']) {
     echo '<div class="group">';
-    echo '<h2>' . __('Web server') . '</h2>';
+    echo '<h2>' , __('Web server') , '</h2>';
     echo '<ul>';
     if ($GLOBALS['cfg']['ShowServerInfo']) {
         PMA_printListItem($_SERVER['SERVER_SOFTWARE'], 'li_web_server_software');
@@ -329,13 +335,13 @@ if ($GLOBALS['cfg']['ShowServerInfo'] || $GLOBALS['cfg']['ShowPhpInfo']) {
             );
 
             $php_ext_string = __('PHP extension:') . ' ';
-            if (PMA_DatabaseInterface::checkDbExtension('mysqli')) {
-                $extension = 'mysqli';
-            } else {
-                $extension = 'mysql';
+
+            $extensions = PMA\libraries\Util::listPHPExtensions();
+
+            foreach ($extensions as $extension) {
+                $php_ext_string  .= '  ' . $extension
+                    . PMA\libraries\Util::showPHPDocu('book.' . $extension . '.php');
             }
-            $php_ext_string  .= $extension . ' '
-                . PMA_Util::showPHPDocu('book.' . $extension . '.php');
 
             PMA_printListItem(
                 $php_ext_string,
@@ -368,11 +374,7 @@ echo '<div class="group pmagroup">';
 echo '<h2>phpMyAdmin</h2>';
 echo '<ul>';
 $class = null;
-// We rely on CSP to allow access to http://www.phpmyadmin.net, but IE lacks
-// support here and does not allow request to http once using https.
-if ($GLOBALS['cfg']['VersionCheck']
-    && (! $GLOBALS['PMA_Config']->get('is_https') || PMA_USR_BROWSER_AGENT != 'IE')
-) {
+if ($GLOBALS['cfg']['VersionCheck']) {
     $class = 'jsversioncheck';
 }
 PMA_printListItem(
@@ -387,14 +389,7 @@ PMA_printListItem(
 PMA_printListItem(
     __('Documentation'),
     'li_pma_docs',
-    PMA_Util::getDocuLink('index'),
-    null,
-    '_blank'
-);
-PMA_printListItem(
-    __('Wiki'),
-    'li_pma_wiki',
-    PMA_linkURL('http://wiki.phpmyadmin.net/'),
+    PMA\libraries\Util::getDocuLink('index'),
     null,
     '_blank'
 );
@@ -403,7 +398,7 @@ PMA_printListItem(
 PMA_printListItem(
     __('Official Homepage'),
     'li_pma_homepage',
-    PMA_linkURL('http://www.phpMyAdmin.net/'),
+    PMA_linkURL('https://www.phpmyadmin.net/'),
     null,
     '_blank'
 );
@@ -428,6 +423,13 @@ PMA_printListItem(
     null,
     '_blank'
 );
+PMA_printListItem(
+    __('License'),
+    'li_pma_license',
+    'license.php' . PMA_URL_getCommon(),
+    null,
+    '_blank'
+);
 echo '    </ul>';
 echo ' </div>';
 
@@ -435,40 +437,6 @@ echo '</div>';
 
 echo '</div>';
 
-/**
- * Warning if using the default MySQL privileged account
- */
-if ($server != 0
-    && $cfg['Server']['user'] == 'root'
-    && $cfg['Server']['password'] == ''
-) {
-    trigger_error(
-        __(
-            'You are connected as \'root\' with no password, which'
-            . ' corresponds to the default MySQL privileged account.'
-            . ' Your MySQL server is running with this default, is open to'
-            . ' intrusion, and you really should fix this security hole by'
-            . ' setting a password for user \'root\'.'
-        ),
-        E_USER_WARNING
-    );
-}
-
-/**
- * As we try to handle charsets by ourself, mbstring overloads just
- * break it, see bug 1063821.
- */
-if (@extension_loaded('mbstring') && @ini_get('mbstring.func_overload') > 1) {
-    trigger_error(
-        __(
-            'You have enabled mbstring.func_overload in your PHP '
-            . 'configuration. This option is incompatible with phpMyAdmin '
-            . 'and might cause some data to be corrupted!'
-        ),
-        E_USER_WARNING
-    );
-}
-
 /**
  * mbstring is used for handling multibytes inside parser, so it is good
  * to tell user something might be broken without it, see bug #1063149.
@@ -485,6 +453,19 @@ if (! @extension_loaded('mbstring')) {
     );
 }
 
+/**
+ * Missing functionality
+ */
+if (! extension_loaded('curl') && ! ini_get('allow_url_fopen')) {
+    trigger_error(
+        __(
+            'The curl extension was not found and allow_url_fopen is '
+            . 'disabled. Due to this some features such as error reporting '
+            . 'or version check are disabled.'
+        )
+    );
+}
+
 if ($cfg['LoginCookieValidityDisableWarning'] == false) {
     /**
      * Check whether session.gc_maxlifetime limits session validity.
@@ -492,7 +473,13 @@ if ($cfg['LoginCookieValidityDisableWarning'] == false) {
     $gc_time = (int)@ini_get('session.gc_maxlifetime');
     if ($gc_time < $GLOBALS['cfg']['LoginCookieValidity'] ) {
         trigger_error(
-            __('Your PHP parameter [a@http://php.net/manual/en/session.configuration.php#ini.session.gc-maxlifetime@_blank]session.gc_maxlifetime[/a] is lower than cookie validity configured in phpMyAdmin, because of this, your login might expire sooner than configured in phpMyAdmin.'),
+            __(
+                'Your PHP parameter [a@https://php.net/manual/en/session.' .
+                'configuration.php#ini.session.gc-maxlifetime@_blank]session.' .
+                'gc_maxlifetime[/a] is lower than cookie validity configured ' .
+                'in phpMyAdmin, because of this, your login might expire sooner ' .
+                'than configured in phpMyAdmin.'
+            ),
             E_USER_WARNING
         );
     }
@@ -505,7 +492,11 @@ if ($GLOBALS['cfg']['LoginCookieStore'] != 0
     && $GLOBALS['cfg']['LoginCookieStore'] < $GLOBALS['cfg']['LoginCookieValidity']
 ) {
     trigger_error(
-        __('Login cookie store is lower than cookie validity configured in phpMyAdmin, because of this, your login will expire sooner than configured in phpMyAdmin.'),
+        __(
+            'Login cookie store is lower than cookie validity configured in ' .
+            'phpMyAdmin, because of this, your login will expire sooner than ' .
+            'configured in phpMyAdmin.'
+        ),
         E_USER_WARNING
     );
 }
@@ -513,22 +504,37 @@ if ($GLOBALS['cfg']['LoginCookieStore'] != 0
 /**
  * Check if user does not have defined blowfish secret and it is being used.
  */
-if (! empty($_SESSION['encryption_key'])
-    && empty($GLOBALS['cfg']['blowfish_secret'])
-) {
-    trigger_error(
-        __('The configuration file now needs a secret passphrase (blowfish_secret).'),
-        E_USER_WARNING
-    );
+if (! empty($_SESSION['encryption_key'])) {
+    if (empty($GLOBALS['cfg']['blowfish_secret'])) {
+        trigger_error(
+            __(
+                'The configuration file now needs a secret passphrase (blowfish_secret).'
+            ),
+            E_USER_WARNING
+        );
+    } elseif (strlen($GLOBALS['cfg']['blowfish_secret']) < 32) {
+        trigger_error(
+            __(
+                'The secret passphrase in configuration (blowfish_secret) is too short.'
+            ),
+            E_USER_WARNING
+        );
+    }
 }
 
 /**
  * Check for existence of config directory which should not exist in
  * production environment.
  */
-if (file_exists('config')) {
+if (@file_exists('config')) {
     trigger_error(
-        __('Directory [code]config[/code], which is used by the setup script, still exists in your phpMyAdmin directory. It is strongly recommended to remove it once phpMyAdmin has been configured. Otherwise the security of your server may be compromised by unauthorized people downloading your configuration.'),
+        __(
+            'Directory [code]config[/code], which is used by the setup script, ' .
+            'still exists in your phpMyAdmin directory. It is strongly ' .
+            'recommended to remove it once phpMyAdmin has been configured. ' .
+            'Otherwise the security of your server may be compromised by ' .
+            'unauthorized people downloading your configuration.'
+        ),
         E_USER_WARNING
     );
 }
@@ -544,15 +550,15 @@ if ($server > 0) {
             . '%sFind out why%s. '
         );
         if ($cfg['ZeroConf'] == true) {
-            $msg_text .= '<br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;' .
+            $msg_text .= '<br>' .
                 __(
                     'Or alternately go to \'Operations\' tab of any database '
                     . 'to set it up there.'
                 );
         }
-        $msg = PMA_Message::notice($msg_text);
+        $msg = PMA\libraries\Message::notice($msg_text);
         $msg->addParam(
-            '<a href="' . $cfg['PmaAbsoluteUri'] . 'chk_rel.php'
+            '<a href="./chk_rel.php'
             . $common_url_query . '">',
             false
         );
@@ -571,22 +577,16 @@ if ($server > 0) {
  * If someday there is a constant that we can check about mysqlnd,
  * we can use it instead of strpos().
  * If no default server is set, $GLOBALS['dbi'] is not defined yet.
- * Drizzle can speak MySQL protocol, so don't warn about version mismatch for
- * Drizzle servers.
  * We also do not warn if MariaDB is detected, as it has its own version
  * numbering.
  */
 if (isset($GLOBALS['dbi'])
-    && !PMA_DRIZZLE
     && $cfg['ServerLibraryDifference_DisableWarning'] == false
 ) {
-    /** @var PMA_String $pmaString */
-    $pmaString = $GLOBALS['PMA_String'];
-
     $_client_info = $GLOBALS['dbi']->getClientInfo();
     if ($server > 0
-        && /*overload*/mb_strpos($_client_info, 'mysqlnd') === false
-        && /*overload*/mb_strpos(PMA_MYSQL_STR_VERSION, 'MariaDB') === false
+        && mb_strpos($_client_info, 'mysqlnd') === false
+        && mb_strpos(PMA_MYSQL_STR_VERSION, 'MariaDB') === false
         && substr(PMA_MYSQL_CLIENT_API, 0, 3) != substr(
             PMA_MYSQL_INT_VERSION, 0, 3
         )
@@ -594,7 +594,11 @@ if (isset($GLOBALS['dbi'])
         trigger_error(
             PMA_sanitize(
                 sprintf(
-                    __('Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.'),
+                    __(
+                        'Your PHP MySQL library version %s differs from your ' .
+                        'MySQL server version %s. This may cause unpredictable ' .
+                        'behavior.'
+                    ),
                     $_client_info,
                     substr(
                         PMA_MYSQL_STR_VERSION,
@@ -618,7 +622,10 @@ if ($cfg['SuhosinDisableWarning'] == false
 ) {
     trigger_error(
         sprintf(
-            __('Server running with Suhosin. Please refer to %sdocumentation%s for possible issues.'),
+            __(
+                'Server running with Suhosin. Please refer to %sdocumentation%s ' .
+                'for possible issues.'
+            ),
             '[doc@faq1-38]',
             '[/doc]'
         ),
@@ -631,7 +638,7 @@ if ($cfg['SuhosinDisableWarning'] == false
  *
  * The data file is created while creating release by ./scripts/remove-incomplete-mo
  */
-if (file_exists('libraries/language_stats.inc.php')) {
+if (@file_exists('libraries/language_stats.inc.php')) {
     include 'libraries/language_stats.inc.php';
     /*
      * This message is intentionally not translated, because we're
@@ -669,33 +676,19 @@ function PMA_printListItem($name, $listId = null, $url = null,
     $mysql_help_page = null, $target = null, $a_id = null, $class = null,
     $a_class = null
 ) {
-    echo '<li id="' . $listId . '"';
-    if (null !== $class) {
-        echo ' class="' . $class . '"';
-    }
-    echo '>';
-    if (null !== $url) {
-        echo '<a href="' . $url . '"';
-        if (null !== $target) {
-            echo ' target="' . $target . '"';
-        }
-        if (null != $a_id) {
-            echo ' id="' . $a_id . '"';
-        }
-        if (null != $a_class) {
-            echo ' class="' . $a_class . '"';
-        }
-        echo '>';
-    }
-
-    echo $name;
-
-    if (null !== $url) {
-        echo '</a>' . "\n";
-    }
-    if (null !== $mysql_help_page) {
-        echo PMA_Util::showMySQLDocu($mysql_help_page);
-    }
-    echo '</li>';
+    echo PMA\libraries\Template::get('list/item')
+        ->render(
+            array(
+                'content' => $name,
+                'id' => $listId,
+                'class' => $class,
+                'url' => array(
+                    'href' => $url,
+                    'target' => $target,
+                    'id' => $a_id,
+                    'class' => $a_class,
+                ),
+                'mysql_help_page' => $mysql_help_page,
+            )
+        );
 }
-?>
