@@ -22,13 +22,11 @@
  * Unbind all event handlers before tearing down a page
  */
 AJAX.registerTeardown('db_structure.js', function () {
-    $("span.fkc_switch").unbind('click');
-    $('#fkc_checkbox').unbind('change');
-    $("a.truncate_table_anchor.ajax").die('click');
-    $("a.drop_table_anchor.ajax").die('click');
-    $('a.drop_tracking_anchor.ajax').die('click');
-    $('#real_end_input').die('click');
-    $("a.favorite_table_anchor.ajax").die('click');
+    $(document).off('click', "a.truncate_table_anchor.ajax");
+    $(document).off('click', "a.drop_table_anchor.ajax");
+    $(document).off('click', '#real_end_input');
+    $(document).off('click', "a.favorite_table_anchor.ajax");
+    $(document).off('click', '#printView');
     $('a.real_row_count').off('click');
     $('a.row_count_sum').off('click');
     $('select[name=submit_mult]').unbind('change');
@@ -39,7 +37,7 @@ AJAX.registerTeardown('db_structure.js', function () {
  * when truncating, creating, dropping or inserting into a table
  */
 function PMA_adjustTotals() {
-    var byteUnits = new Array(
+    var byteUnits = [
         PMA_messages.strB,
         PMA_messages.strKiB,
         PMA_messages.strMiB,
@@ -47,11 +45,11 @@ function PMA_adjustTotals() {
         PMA_messages.strTiB,
         PMA_messages.strPiB,
         PMA_messages.strEiB
-    );
+    ];
     /**
      * @var $allTr jQuery object that references all the rows in the list of tables
      */
-    var $allTr = $("#tablesForm table.data tbody:first tr");
+    var $allTr = $("#tablesForm").find("table.data tbody:first tr");
     // New summary values for the table
     var tableSum = $allTr.size();
     var rowsSum = 0;
@@ -128,8 +126,12 @@ function PMA_adjustTotals() {
 
     // Update summary with new data
     var $summary = $("#tbl_summary_row");
-    $summary.find('.tbl_num').text(PMA_sprintf(PMA_messages.strTables, tableSum));
-    $summary.find('.row_count_sum').text(strRowSum);
+    $summary.find('.tbl_num').text(PMA_sprintf(PMA_messages.strNTables, tableSum));
+    if (rowSumApproximated) {
+        $summary.find('.row_count_sum').text(strRowSum);
+    } else {
+        $summary.find('.tbl_rows').text(strRowSum);
+    }
     $summary.find('.tbl_size').text(sizeSum + " " + byteUnits[size_magnitude]);
     $summary.find('.tbl_overhead').text(overheadSum + " " + byteUnits[overhead_magnitude]);
 }
@@ -140,7 +142,7 @@ function PMA_adjustTotals() {
  */
 function PMA_fetchRealRowCount($target)
 {
-    var $throbber = $('#pma_navigation .throbber')
+    var $throbber = $('#pma_navigation').find('.throbber')
         .first()
         .clone()
         .css({visibility: 'visible', display: 'inline-block'})
@@ -181,31 +183,6 @@ function PMA_fetchRealRowCount($target)
 }
 
 AJAX.registerOnload('db_structure.js', function () {
-    /**
-     * Handler for the print view multisubmit.
-     * All other multi submits can be handled via ajax, but this one needs
-     * special treatment as the results need to open in another browser window
-     */
-    $('#tablesForm').submit(function (event) {
-        var $form = $(this);
-        if ($form.find('select[name=submit_mult]').val() === 'print') {
-            event.preventDefault();
-            event.stopPropagation();
-            $('form#clone').remove();
-            var $clone = $form
-                .clone()
-                .hide()
-                .appendTo('body');
-            $clone
-                .find('select[name=submit_mult]')
-                .val('print');
-            $clone
-                .attr('target', 'printview')
-                .attr('id', 'clone')
-                .submit();
-        }
-    });
-
 /**
  * function to open the confirmation dialog for making table consistent with central list
  *
@@ -237,7 +214,7 @@ AJAX.registerOnload('db_structure.js', function () {
  *  Event handler on select of "Make consistent with central list"
  */
     $('select[name=submit_mult]').change(function(event) {
-        if($(this).val() === 'make_consistent_with_central_list') {
+        if ($(this).val() === 'make_consistent_with_central_list') {
             event.preventDefault();
             event.stopPropagation();
             jqConfirm(PMA_messages.makeConsistentMessage, function(){
@@ -245,33 +222,63 @@ AJAX.registerOnload('db_structure.js', function () {
                     });
             return false;
         }
-    });
-     /**
-     * Event handler for 'Foreign Key Checks' disabling option
-     * in the drop table confirmation form
-     */
-    $("span.fkc_switch").click(function (event) {
-        if ($("#fkc_checkbox").prop('checked')) {
-            $("#fkc_checkbox").prop('checked', false);
-            $("#fkc_status").html(PMA_messages.strForeignKeyCheckDisabled);
-            return;
-        }
-        $("#fkc_checkbox").prop('checked', true);
-        $("#fkc_status").html(PMA_messages.strForeignKeyCheckEnabled);
-    });
+        else if ($(this).val() === 'copy_tbl' || $(this).val() === 'add_prefix_tbl' || $(this).val() === 'replace_prefix_tbl' || $(this).val() === 'copy_tbl_change_prefix') {
+            event.preventDefault();
+            event.stopPropagation();
+            if ($('input[name="selected_tbl[]"]:checked').length === 0) {
+                return false;
+            }
+            var formData = $('#tablesForm').serialize();
+            var modalTitle = '';
+            if ($(this).val() === 'copy_tbl') {
+                modalTitle = PMA_messages.strCopyTablesTo;
+            }
+            else if ($(this).val() === 'add_prefix_tbl') {
+                modalTitle = PMA_messages.strAddPrefix;
+            }
+            else if ($(this).val() === 'replace_prefix_tbl') {
+                modalTitle = PMA_messages.strReplacePrefix;
+            }
+            else if ($(this).val() === 'copy_tbl_change_prefix') {
+                modalTitle = PMA_messages.strCopyPrefix;
+            }
+            $.ajax({
+                type: 'POST',
+                url: 'db_structure.php',
+                dataType: 'html',
+                data: formData
 
-    $('#fkc_checkbox').change(function () {
-        if ($(this).prop("checked")) {
-            $("#fkc_status").html(PMA_messages.strForeignKeyCheckEnabled);
-            return;
+            }).done(function(data) {
+
+                var dialogObj = $("<div style='display:none'>"+data+"</div>");
+                $('body').append(dialogObj);
+                var buttonOptions = {};
+                buttonOptions[PMA_messages.strContinue] = function () {
+                    $('#ajax_form').submit();
+                    $( this ).dialog( "close" );
+                };
+                buttonOptions[PMA_messages.strCancel] = function () {
+                    $( this ).dialog( "close" );
+                    $('#tablesForm')[0].reset();
+                };
+                $(dialogObj).dialog({
+                    minWidth: 500,
+                    resizable: false,
+                    modal: true,
+                    title: modalTitle,
+                    buttons: buttonOptions
+                });
+            });
         }
-        $("#fkc_status").html(PMA_messages.strForeignKeyCheckDisabled);
-    }); // End of event handler for 'Foreign Key Check'
+        else {
+            $('#tablesForm').submit();
+        }
+    });
 
     /**
      * Ajax Event handler for 'Truncate Table'
      */
-    $("a.truncate_table_anchor.ajax").live('click', function (event) {
+    $(document).on('click', "a.truncate_table_anchor.ajax", function (event) {
         event.preventDefault();
 
         /**
@@ -288,13 +295,16 @@ AJAX.registerOnload('db_structure.js', function () {
          * @var question    String containing the question to be asked for confirmation
          */
         var question = PMA_messages.strTruncateTableStrongWarning + ' ' +
-            PMA_sprintf(PMA_messages.strDoYouReally, 'TRUNCATE ' + escapeHtml(curr_table_name));
+            PMA_sprintf(PMA_messages.strDoYouReally, 'TRUNCATE ' + escapeHtml(curr_table_name)) +
+            getForeignKeyCheckboxLoader();
 
         $this_anchor.PMA_confirm(question, $this_anchor.attr('href'), function (url) {
 
             PMA_ajaxShowMessage(PMA_messages.strProcessingRequest);
 
-            $.get(url, {'is_js_confirmed' : 1, 'ajax_request' : true}, function (data) {
+            var params = getJSConfirmCommonParam(this);
+
+            $.post(url, params, function (data) {
                 if (typeof data !== 'undefined' && data.success === true) {
                     PMA_ajaxShowMessage(data.message);
                     // Adjust table statistics
@@ -313,14 +323,14 @@ AJAX.registerOnload('db_structure.js', function () {
                 } else {
                     PMA_ajaxShowMessage(PMA_messages.strErrorProcessingRequest + " : " + data.error, false);
                 }
-            }); // end $.get()
-        }); //end $.PMA_confirm()
+            }); // end $.post()
+        }, loadForeignKeyCheckbox); //end $.PMA_confirm()
     }); //end of Truncate Table Ajax action
 
     /**
      * Ajax Event handler for 'Drop Table' or 'Drop View'
      */
-    $("a.drop_table_anchor.ajax").live('click', function (event) {
+    $(document).on('click', "a.drop_table_anchor.ajax", function (event) {
         event.preventDefault();
 
         var $this_anchor = $(this);
@@ -349,12 +359,15 @@ AJAX.registerOnload('db_structure.js', function () {
             question =
                 PMA_sprintf(PMA_messages.strDoYouReally, 'DROP VIEW ' + escapeHtml(curr_table_name));
         }
+        question += getForeignKeyCheckboxLoader();
 
         $this_anchor.PMA_confirm(question, $this_anchor.attr('href'), function (url) {
 
             var $msg = PMA_ajaxShowMessage(PMA_messages.strProcessingRequest);
 
-            $.get(url, {'is_js_confirmed' : 1, 'ajax_request' : true}, function (data) {
+            var params = getJSConfirmCommonParam(this);
+
+            $.post(url, params, function (data) {
                 if (typeof data !== 'undefined' && data.success === true) {
                     PMA_ajaxShowMessage(data.message);
                     toggleRowColors($curr_row.next());
@@ -365,100 +378,26 @@ AJAX.registerOnload('db_structure.js', function () {
                 } else {
                     PMA_ajaxShowMessage(PMA_messages.strErrorProcessingRequest + " : " + data.error, false);
                 }
-            }); // end $.get()
-        }); // end $.PMA_confirm()
+            }); // end $.post()
+        }, loadForeignKeyCheckbox); // end $.PMA_confirm()
     }); //end of Drop Table Ajax action
 
     /**
-     * Ajax Event handler for 'Drop tracking'
+     * Attach Event Handler for 'Print' link
      */
-    $('a.drop_tracking_anchor.ajax').live('click', function (event) {
+    $(document).on('click', "#printView", function (event) {
         event.preventDefault();
 
-        var $anchor = $(this);
-
-        /**
-         * @var curr_tracking_row   Object containing reference to the current tracked table's row
-         */
-        var $curr_tracking_row = $anchor.parents('tr');
-         /**
-         * @var question    String containing the question to be asked for confirmation
-         */
-        var question = PMA_messages.strDeleteTrackingData;
-
-        $anchor.PMA_confirm(question, $anchor.attr('href'), function (url) {
-
-            PMA_ajaxShowMessage(PMA_messages.strDeletingTrackingData);
-
-            $.get(url, {'is_js_confirmed': 1, 'ajax_request': true}, function (data) {
-                if (typeof data !== 'undefined' && data.success === true) {
-                    var $tracked_table = $curr_tracking_row.parents('table');
-                    var table_name = $curr_tracking_row.find('td:nth-child(2)').text();
-
-                    // Check how many rows will be left after we remove
-                    if ($tracked_table.find('tbody tr').length === 1) {
-                        // We are removing the only row it has
-                        $('#tracked_tables').hide("slow").remove();
-                    } else {
-                        // There are more rows left after the deletion
-                        toggleRowColors($curr_tracking_row.next());
-                        $curr_tracking_row.hide("slow", function () {
-                            $(this).remove();
-                        });
-                    }
-
-                    // Make the removed table visible in the list of 'Untracked tables'.
-                    var $untracked_table = $('table#noversions');
-
-                    // This won't work if no untracked tables are there.
-                    if ($untracked_table.length > 0) {
-                        var $rows = $untracked_table.find('tbody tr');
-
-                        $rows.each(function (index) {
-                            var $row = $(this);
-                            var tmp_tbl_name = $row.find('td:first-child').text();
-                            var is_last_iteration = (index == ($rows.length - 1));
-
-                            if (tmp_tbl_name > table_name || is_last_iteration) {
-                                var $cloned = $row.clone();
-
-                                // Change the table name of the cloned row.
-                                $cloned.find('td:first-child').text(table_name);
-
-                                // Change the link of the cloned row.
-                                var new_url = $cloned
-                                    .find('td:nth-child(2) a')
-                                    .attr('href')
-                                    .replace('table=' + tmp_tbl_name, 'table=' + encodeURIComponent(table_name));
-                                $cloned.find('td:nth-child(2) a').attr('href', new_url);
-
-                                // Insert the cloned row in an appropriate location.
-                                if (tmp_tbl_name > table_name) {
-                                    $cloned.insertBefore($row);
-                                    toggleRowColors($row);
-                                    return false;
-                                } else {
-                                    $cloned.insertAfter($row);
-                                    toggleRowColors($cloned);
-                                }
-                            }
-                        });
-                    }
-
-                    PMA_ajaxShowMessage(data.message);
-                } else {
-                    PMA_ajaxShowMessage(PMA_messages.strErrorProcessingRequest + " : " + data.error, false);
-                }
-            }); // end $.get()
-        }); // end $.PMA_confirm()
-    }); //end Drop Tracking
+        // Take to preview mode
+        printPreview();
+    }); //end of Print View action
 
     //Calculate Real End for InnoDB
     /**
      * Ajax Event handler for calculating the real end for a InnoDB table
      *
      */
-    $('#real_end_input').live('click', function (event) {
+    $(document).on('click', '#real_end_input', function (event) {
         event.preventDefault();
 
         /**
@@ -472,11 +411,6 @@ AJAX.registerOnload('db_structure.js', function () {
         return false;
     }); //end Calculate Real End for InnoDB
 
-    PMA_tooltip(
-        $("select[name*='funcs']"),
-        'select',
-        PMA_messages.strFunctionHint
-    );
     // Add tooltip to favorite icons.
     $(".favorite_table_anchor").each(function () {
         PMA_tooltip(
