@@ -1,6 +1,5 @@
 <?php
 /* vim: set expandtab sw=4 ts=4 sts=4: */
-
 /**
  * functions for displaying processes list
  *
@@ -8,9 +7,9 @@
  *
  * @package PhpMyAdmin
  */
-if (! defined('PHPMYADMIN')) {
-    exit;
-}
+use PMA\libraries\Message;
+use PMA\libraries\ServerStatusData;
+use PMA\libraries\Util;
 
 /**
  * Prints html for auto refreshing processes list
@@ -19,7 +18,7 @@ if (! defined('PHPMYADMIN')) {
  */
 function PMA_getHtmlForProcessListAutoRefresh()
 {
-    $notice = PMA_Message::notice(
+    $notice = Message::notice(
         __(
             'Note: Enabling the auto refresh here might cause '
             . 'heavy traffic between the web server and the MySQL server.'
@@ -27,14 +26,14 @@ function PMA_getHtmlForProcessListAutoRefresh()
     )->getDisplay();
     $retval  = $notice . '<div class="tabLinks">';
     $retval .= '<label>' . __('Refresh rate') . ': ';
-    $retval .= PMA_ServerStatusData::getHtmlForRefreshList(
+    $retval .= ServerStatusData::getHtmlForRefreshList(
         'refreshRate',
         5,
         Array(2, 3, 4, 5, 10, 20, 40, 60, 120, 300, 600, 1200)
     );
     $retval .= '</label>';
     $retval .= '<a id="toggleRefresh" href="#">';
-    $retval .= PMA_Util::getImage('play.png') . __('Start auto refresh');
+    $retval .= Util::getImage('play.png') . __('Start auto refresh');
     $retval .= '</a>';
     $retval .= '</div>';
     return $retval;
@@ -103,49 +102,22 @@ function PMA_getHtmlForServerProcesslist()
     );
     $sortableColCount = count($sortable_columns);
 
-    if (PMA_DRIZZLE) {
-        $left_str = 'left(p.info, '
-            . (int)$GLOBALS['cfg']['MaxCharactersInDisplayedSQL'] . ')';
-        $sql_query = "SELECT
-                p.id       AS Id,
-                p.username AS User,
-                p.host     AS Host,
-                p.db       AS db,
-                p.command  AS Command,
-                p.time     AS Time,
-                p.state    AS State,"
-                . ($show_full_sql ? 's.query' : $left_str )
-                . " AS Info FROM data_dictionary.PROCESSLIST p "
-                . ($show_full_sql
-                ? 'LEFT JOIN data_dictionary.SESSIONS s ON s.session_id = p.id'
-                : '');
-        if (! empty($_REQUEST['showExecuting'])) {
-            $sql_query .= ' WHERE p.state = "executing" ';
-        }
-        if (! empty($_REQUEST['order_by_field'])
-            && ! empty($_REQUEST['sort_order'])
-        ) {
-            $sql_query .= ' ORDER BY p.' . $_REQUEST['order_by_field'] . ' '
-                 . $_REQUEST['sort_order'];
-        }
-    } else {
-        $sql_query = $show_full_sql
-            ? 'SHOW FULL PROCESSLIST'
-            : 'SHOW PROCESSLIST';
-        if ((! empty($_REQUEST['order_by_field'])
-            && ! empty($_REQUEST['sort_order']))
-            || (! empty($_REQUEST['showExecuting']))
-        ) {
-            $sql_query = 'SELECT * FROM `INFORMATION_SCHEMA`.`PROCESSLIST` ';
-        }
-        if (! empty($_REQUEST['showExecuting'])) {
-            $sql_query .= ' WHERE state = "executing" ';
-        }
-        if (!empty($_REQUEST['order_by_field']) && !empty($_REQUEST['sort_order'])) {
-            $sql_query .= ' ORDER BY '
-                . PMA_Util::backquote($_REQUEST['order_by_field'])
-                . ' ' . $_REQUEST['sort_order'];
-        }
+    $sql_query = $show_full_sql
+        ? 'SHOW FULL PROCESSLIST'
+        : 'SHOW PROCESSLIST';
+    if ((! empty($_REQUEST['order_by_field'])
+        && ! empty($_REQUEST['sort_order']))
+        || (! empty($_REQUEST['showExecuting']))
+    ) {
+        $sql_query = 'SELECT * FROM `INFORMATION_SCHEMA`.`PROCESSLIST` ';
+    }
+    if (! empty($_REQUEST['showExecuting'])) {
+        $sql_query .= ' WHERE state != "" ';
+    }
+    if (!empty($_REQUEST['order_by_field']) && !empty($_REQUEST['sort_order'])) {
+        $sql_query .= ' ORDER BY '
+            . Util::backquote($_REQUEST['order_by_field'])
+            . ' ' . $_REQUEST['sort_order'];
     }
 
     $result = $GLOBALS['dbi']->query($sql_query);
@@ -197,15 +169,15 @@ function PMA_getHtmlForServerProcesslist()
 
         $retval .= '</a>';
 
-        if (! PMA_DRIZZLE && (0 === --$sortableColCount)) {
+        if (0 === --$sortableColCount) {
             $retval .= '<a href="' . $full_text_link . '">';
             if ($show_full_sql) {
-                $retval .= PMA_Util::getImage(
+                $retval .= Util::getImage(
                     's_partialtext.png',
                     __('Truncate Shown Queries')
                 );
             } else {
-                $retval .= PMA_Util::getImage(
+                $retval .= Util::getImage(
                     's_fulltext.png',
                     __('Show Full Queries')
                 );
@@ -277,7 +249,7 @@ function PMA_getHtmlForProcessListFilter()
 /**
  * Prints Every Item of Server Process
  *
- * @param Array $process       data of Every Item of Server Process
+ * @param array $process       data of Every Item of Server Process
  * @param bool  $odd_row       display odd row or not
  * @param bool  $show_full_sql show full sql or not
  *
@@ -291,7 +263,7 @@ function PMA_getHtmlForServerProcessItem($process, $odd_row, $show_full_sql)
         || (! empty($_REQUEST['showExecuting']))
     ) {
         foreach (array_keys($process) as $key) {
-            $new_key = ucfirst(/*overload*/mb_strtolower($key));
+            $new_key = ucfirst(mb_strtolower($key));
             if ($new_key !== $key) {
                 $process[$new_key] = $process[$key];
                 unset($process[$key]);
@@ -312,7 +284,7 @@ function PMA_getHtmlForServerProcessItem($process, $odd_row, $show_full_sql)
     $retval .= '<td>' . htmlspecialchars($process['User']) . '</td>';
     $retval .= '<td>' . htmlspecialchars($process['Host']) . '</td>';
     $retval .= '<td>' . ((! isset($process['db'])
-            || !/*overload*/mb_strlen($process['db']))
+            || !mb_strlen($process['db']))
             ? '<i>' . __('None') . '</i>'
             : htmlspecialchars($process['db'])) . '</td>';
     $retval .= '<td>' . htmlspecialchars($process['Command']) . '</td>';
@@ -326,7 +298,7 @@ function PMA_getHtmlForServerProcessItem($process, $odd_row, $show_full_sql)
     if (empty($process['Info'])) {
         $retval .= '---';
     } else {
-        $retval .= PMA_Util::formatSql($process['Info'], ! $show_full_sql);
+        $retval .= Util::formatSql($process['Info'], ! $show_full_sql);
     }
     $retval .= '</td>';
     $retval .= '</tr>';
