@@ -6,10 +6,6 @@
  * @package PhpMyAdmin
  */
 
-if (! defined('PHPMYADMIN')) {
-    exit;
-}
-
 /**
  * Get HTML for secondary level menu tabs on 'Users' page
  *
@@ -22,7 +18,7 @@ function PMA_getHtmlForSubMenusOnUsersPage($selfUrl)
     $url_params = PMA_URL_getCommon();
     $items = array(
         array(
-            'name' => __('Users overview'),
+            'name' => __('User accounts overview'),
             'url' => 'server_privileges.php',
             'specific_params' => '&viewing_mode=server'
         )
@@ -55,4 +51,3 @@ function PMA_getHtmlForSubMenusOnUsersPage($selfUrl)
 
     return $retval;
 }
-?>
\ No newline at end of file
