@@ -1,7 +1,7 @@
 <?php
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
- ** Test for PMA_Util::showPHPDocu from Util.class.php
+ ** Test for PMA\libraries\Util::showPHPDocu from Util.php
  *
  * @package PhpMyAdmin-test
  * @group common.lib-tests
@@ -10,13 +10,13 @@
 /*
  * Include to test.
  */
-require_once 'libraries/core.lib.php';
-require_once 'libraries/Util.class.php';
-require_once 'libraries/Theme.class.php';
-require_once 'libraries/php-gettext/gettext.inc';
+use PMA\libraries\Theme;
+
+
+
 
 /**
- ** Test for PMA_Util::showPHPDocu from Util.class.php
+ ** Test for PMA\libraries\Util::showPHPDocu from Util.php
  *
  * @package PhpMyAdmin-test
  * @group common.lib-tests
@@ -30,7 +30,7 @@ class PMA_ShowPHPDocu_Test extends PHPUnit_Framework_TestCase
      */
     function setup()
     {
-        $_SESSION['PMA_Theme'] = PMA_Theme::load('./themes/pmahomme');
+        $_SESSION['PMA_Theme'] = Theme::load('./themes/pmahomme');
         $GLOBALS['server'] = 99;
         $GLOBALS['cfg']['ServerDefault'] = 0;
     }
@@ -44,13 +44,13 @@ class PMA_ShowPHPDocu_Test extends PHPUnit_Framework_TestCase
     {
         $target = "docu";
         $lang = _pgettext('PHP documentation language', 'en');
-        $expected = '<a href="./url.php?url=http%3A%2F%2Fphp.net%2Fmanual%2F' . $lang
+        $expected = '<a href="./url.php?url=https%3A%2F%2Fphp.net%2Fmanual%2F' . $lang
             . '%2F' . $target . '" target="documentation">'
             . '<img src="themes/dot.gif" title="' . __('Documentation') . '" alt="'
             . __('Documentation') . '" class="icon ic_b_help" /></a>';
 
         $this->assertEquals(
-            $expected, PMA_Util::showPHPDocu($target)
+            $expected, PMA\libraries\Util::showPHPDocu($target)
         );
     }
 }
